<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:java="http://xml.apache.org/xslt/java"
	xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
	xmlns:gslib="http://www.greenstone.org/skinning"
	xmlns:gsf="http://www.greenstone.org/greenstone3/schema/ConfigFormat"
	xmlns:xlink="http://www.w3.org/1999/xlink" 
	extension-element-prefixes="java util"
	exclude-result-prefixes="java util gsf">
  

  <!-- *** -->
  <!-- Document header -->
  <!-- *** -->

  <xsl:template name="soundmanager2-header">

    <!-- soundManager2 API -->
    <gsf:style src="ext/sound-manager2/css/flashblock.css" />  
    <gsf:script src="ext/sound-manager2/script/soundmanager2-nodebug.js"/>

    <!-- The Page player (variant of SoundManger) main script -->
    <gsf:script src="ext/sound-manager2/script/page-player.js"/>
    <gsf:style src="ext/sound-manager2/css/page-player.css" />
        
    <!-- optional: annotations/sub-tracks/notes, and alternate themes -->
    <gsf:style src="ext/sound-manager2/css/optional-annotations.css" />
    <gsf:style src="ext/sound-manager2/css/optional-themes.css" />

    <!-- optional: Metadata UI prototype (not needed unless you want the bottom-most demo bits) -->
    <gsf:script src="ext/sound-manager2/script/optional-page-player-metadata.js"/>
    
    <gsf:style>
      ul.playlist li .comment {font-size:0.65em;opacity:0.5}
    </gsf:style>
    
    <!-- Customization of page-player for this collection -->

    <gsf:script>

      soundManager.flashVersion = 9;
      soundManager.preferFlash = true;        /* for visualization effects */
      soundManager.useHighPerformance = true; /* keep flash on screen, boost performance */
      soundManager.wmode = "transparent";     /* transparent SWF, if possible */
      soundManager.useFastPolling = true;     /* increased JS callback frequency */
      soundManager.url = "ext/sound-manager2/swf/";

      /* custom page player configuration */

      var PP_CONFIG = {
        autoStart:       false,  /* begin playing first sound when page loads */
	playNext:        false,  /* stop after one sound, or play through list until end */
	useThrottling:   false,  /* try to rate-limit potentially-expensive calls (eg. dragging position around) */
	usePeakData:     true,   /* [Flash 9 only] whether or not to show peak data (left/right channel values) - nor noticable on CPU */
	useWaveformData: false,  /* [Flash 9 only] show raw waveform data - WARNING: LIKELY VERY CPU-HEAVY */
	useEQData:       false,  /* [Flash 9 only] show EQ (frequency spectrum) data */
	useFavIcon:      false,  /* try to apply peakData to address bar (Firefox + Opera) - performance note: appears to make Firefox 3 do some temporary, heavy disk access/swapping/garbage collection at first(?) - may be too heavy on CPU */
	useMovieStar:    true    /* Flash 9.0r115+ only: Support for a subset of MPEG4 formats. */
      }
    </gsf:script>
  </xsl:template>


  <!-- CAA = Content Analysis Algorithm -->
  <xsl:variable name="cgiargCAAlgorithm">
    <xsl:choose>
      <xsl:when test="/page/pageRequest/paramList/param[@name='p.caAlgorithm']/@value != ''"><xsl:value-of select="/page/pageRequest/paramList/param[@name='p.caAlgorithm']/@value"/></xsl:when>
      <xsl:otherwise>1</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <!-- *** -->
  <!-- The Javascript DSP files for computing chroma features in the browser -->
  <!-- *** -->

  <xsl:template name="javascript-dsp-header">

    <gsf:script src="ext/js-dsp/dsp-custom.js"/>
    <gsf:script src="ext/js-dsp/dsp.js"/>
    <gsf:script src="ext/js-dsp/chroma-transform.js"/>
    <gsf:script src="ext/js-dsp/frequency-plotter.js"/>
    <gsf:script src="ext/js-dsp/frequency-player.js"/>


    <gsf:script src="ext/js-dsp/component/crockford-inheritance.js"/>
    <gsf:script src="ext/js-dsp/component/workflow-core.js"/>
    <gsf:script src="ext/js-dsp/component/audio-mixer.js"/>
    <gsf:script src="ext/js-dsp/component/wf-freq-spectrum.js"/>
    <gsf:script src="ext/js-dsp/component/wf-filter-bank.js"/>
    <gsf:script src="ext/js-dsp/component/wf-chroma-transform.js"/>
    <gsf:script src="ext/js-dsp/component/active-workflow.js"/>

  </xsl:template>

  <xsl:template name="processingPopup">
    <div>
      <style type="text/css">	
	#processing { 
	  width: 100%; 
	  height: 100%; 
	  position: absolute; 
	  z-index: 10000; 
	  left: 0px; 
	  top: 0px; 
	  background-color: rgba(255,255,255,0.75); 
	  opacity: 1; 
	  display: none;
	}

	#processingMessage { 
	  position: absolute;
	  padding: 10px;
	  border-radius: 10px; 
	  margin-left: 50%; 
	  width: 380px; 
	  height: 105px; 
	  left: -250px; top: 200px; 
	  background-color: rgba(255,255,255,1);
	  box-shadow: 0px 0px 30px rgba(0,0,0,0.8); 
	}

	#processingMessage p { 
	  font-size: 18px; 
	  text-align: center; 
	  font-family: 
	  sans-serif; 
	  font-weight: bold; 
	  color: #666; 
	}
      </style>
      
      <div id="processing">
	<div id="processingMessage">
	  <h2 id="processingTitle" class="ui-state-default ui-corner-all" style="padding: 8px; font-size: 110%; width: auto;">
	    Heading
	  </h2>
	  <p id="processingText">text</p>
	</div>
      </div>
    </div>

  </xsl:template>

  <!-- *** -->
  <!-- * Discovery -->
  <!-- *** -->

  <xsl:template name="discovery-block">
    
    <div id="fingerprint-turnstyle">

      <div style="background-image: none; background-color: #2E52A4;">
	Discovery: <xsl:call-template name="choose-title"/>
      </div>

      <div class="documenttext" style="display: none;">
	<xsl:call-template name="fingerprintMetadataBlock" />
      </div>

    </div>

    <script>
      <xsl:text disable-output-escaping="yes">
	$(function(){
	transformToTurnstyleBlock("fingerprint");
	});
      </xsl:text>
    </script>
    
  </xsl:template>



  <xsl:template name="fingerprintMetadataBlock">
    
    <xsl:variable name="httpCollection"><xsl:value-of select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/></xsl:variable>
    <xsl:variable name="assocFilePath"><gsf:metadata name="assocfilepath" select="root"/></xsl:variable>


    <xsl:variable name="musicbrainzsongid">
      <gsf:metadata name="dc.Identifier.musicbrainzsongid"/>
    </xsl:variable>

    <xsl:variable name="musicbrainzalbumid">
      <gsf:metadata name="dc.Source.musicbrainzalbumid"/>
    </xsl:variable>

    <xsl:variable name="musicbrainzartistid">
      <gsf:metadata name="dc.Creator.musicbrainzartistid"/>
    </xsl:variable>
    
    <xsl:variable name="lastfmtrackurl">
      <gsf:metadata name="dc.Identifier.lastfmtrackurl"/>
    </xsl:variable>

    <xsl:variable name="echonestsongid">
      <gsf:metadata name="dc.Identifier.echonestsongid"/>
    </xsl:variable>
      
      <center>
      <table class="metadata-stripes" style="min-width: 400px;">
	<tbody>
	  <tr>
	    <td>
	      Title
	    </td>
	    <td>
	      <gsf:metadata name="dc.Title"/>
	    </td>
	  </tr>
	  
	  <tr>
	    <td>Album Title</td>
	    <td><gsf:metadata name="dc.Title.albumtitle"/></td>
	  </tr>
	  
	  <tr>
	    <td>Artist</td>
	    <td><gsf:metadata name="dc.Creator"/></td>
	  </tr>

	  <tr>
	    <td>Released</td>
	    <td><gsf:metadata name="dc.Coverage"/></td>
	  </tr>
	  
<!--
	  <tr valign="top">
	    <td>Artist Summary</td>
	    <td>
	      <i>
		<gsf:script>
		  var summary = gs.documentMetadata["LastFM_LastFMArtistWikiSummary"];
		  
		  if (summary) {
  		    document.write(summary.replace("\n","&lt;br /&gt;"));
		  }

		</gsf:script>
	      </i>
	    </td>
	  </tr>
-->

	  
<!--
dc.Identifier.echonestsongid
dc.Identifier.echonestartistid

dc.Identifier.lastfmtrackurl
dc.Identifier.lastfmalbumurl
dc.Identifier.lastfmartisturl

//dc.Identifier
dc.Identifier.musicbrainzalbumid
dc.Identifier.musicbrainzartistid
dc.Identifier.musicbrainzsongid
dc.Identifier.playmeartistid

-->

	  <tr>
	    <td colspan="2">

	      <xsl:for-each select="/page/pageResponse/document/metadataList/metadata[@name = 'dc.Relation.artistrelatedimage']">
		<xsl:if test="position() &lt;= 6">
		  <a target="_blank">
		    <xsl:attribute name='href'>
		      <xsl:value-of disable-output-escaping="yes" select="."/>
		    </xsl:attribute>
		    
		    <img width="150">
		      <xsl:attribute name='src'>
			<xsl:value-of disable-output-escaping="yes" select="."/>
		      </xsl:attribute>
		    </img>
		  </a>
		</xsl:if>
	      </xsl:for-each>
	    </td>
	  </tr>

	  <xsl:if test="$interface_name='dlfm'">
	  <tr>
	    <td>Linked Data</td>
	    <td>
	      <!--
		  <gsf:metadata name="dc.Identifier"/><br />
	      -->

	      <table style="width: 100%;">
		<tr>
		  <td style="width: 200px;">
		    MusicBrainz song id: 
		  </td>
		  <td>
		    <a href="http://dbtune.org/musicbrainz/resource/track/{$musicbrainzsongid}" target="#musicbrainz" class="external">
		      <xsl:copy-of select="$musicbrainzsongid"/>
		    </a>
		  </td>
		</tr>

		<tr>
		  <td>
		    MusicBrainz album id: 
		  </td>
		  <td>
		    <a href="http://dbtune.org/musicbrainz/resource/record/{$musicbrainzalbumid}" target="#musicbrainz" class="external">
		      <xsl:copy-of select="$musicbrainzalbumid"/>
		    </a>
		  </td>
		</tr>

		<tr>
		  <td>
		    MusicBrainz artist id: 
		  </td>
		  <td>
		    <a href="https://musicbrainz.org/artist/{$musicbrainzartistid}" target="#musicbrainz" class="external">
		      <xsl:copy-of select="$musicbrainzartistid"/>
		    </a>
		  </td>
		</tr>
<!--
		<tr>
		  <td>
		    EchoNest song id:
		  </td>
		  <td>
		    <a href="http://developer.echonest.com/api/v4/song/profile?api_key=8WNR9XTGCODO9G4YG&amp;format=xml&amp;id={$echonestsongid}" target="#echonestsongid" class="external">



		      <xsl:copy-of select="$echonestsongid"/>
		    </a>
		  </td>
		</tr>
-->

		<tr>
		  <td colspan="2">	      
		    <i>
		      <a href="{$lastfmtrackurl}" target="#lastfm" class="external">
			<xsl:copy-of select="$lastfmtrackurl"/>
		      </a>
		    </i>
		  </td>
		</tr>
	      </table>

	    </td>
	  </tr>
	  </xsl:if>

	</tbody>
      </table>
      </center>
  </xsl:template>



  <!-- *** -->
  <!-- * Audio Player -->
  <!-- *** -->

  <xsl:template name="js-mad-header">

        <gsf:script src="ext/js-mad/script/mad.js"/>
        <gsf:script src="ext/js-mad/script/rq_table.js"/>
        <gsf:script src="ext/js-mad/script/imdct_s.js"/>
        <gsf:script src="ext/js-mad/script/huffman.js"/>
        <gsf:script src="ext/js-mad/script/bit.js"/>
        <gsf:script src="ext/js-mad/script/stream.js"/>
        <gsf:script src="ext/js-mad/script/layer3.js"/>
        <gsf:script src="ext/js-mad/script/frame.js"/>
        <gsf:script src="ext/js-mad/script/synth.js"/>
       
        <gsf:script src="ext/js-mad/script/arraybuffer/bytestream.js"/>
        <gsf:script src="ext/js-mad/script/arraybuffer/filestream.js"/>
        <gsf:script src="ext/js-mad/script/arraybuffer/substream.js"/>
        <gsf:script src="ext/js-mad/script/arraybuffer/arraystream.js"/>
        <gsf:script src="ext/js-mad/script/arraybuffer/ajaxstream.js"/>

        <gsf:script src="ext/js-mad/script/binarystring/bytestream.js"/>
        <gsf:script src="ext/js-mad/script/binarystring/filestream.js"/>
        <gsf:script src="ext/js-mad/script/binarystring/substream.js"/>
        <gsf:script src="ext/js-mad/script/binarystring/stringstream.js"/>
        <gsf:script src="ext/js-mad/script/binarystring/ajaxstream.js"/>

        <gsf:script src="ext/js-mad/script/id3v22stream.js"/>
        <gsf:script src="ext/js-mad/script/id3v23stream.js"/>
        <gsf:script src="ext/js-mad/script/mp3file.js"/>
        
<!--
        <gsf:script src="ext/js-mad/script/player.js"/>
-->

        <gsf:script src="ext/js-mad/script/sink.min.js"/>

<!--
        <gsf:script src="ext/js-mad/script/require.js"/>
-->
<!--
        <gsf:script src="ext/js-mad/script/sink-light.js"/>
-->

        <gsf:script src="ext/js-mad/script/browser-detect.js"/>
        <gsf:script src="ext/js-mad/script/main-jsmad.js"/>

  </xsl:template>



  <xsl:template name="audio-icon-cache">
    <div style="display:none;">
      <!-- pre-load various play/pause images to help with speed of interface update -->
      <img src="ext/diy-audio-player/images/play32Highlight.png" />
      <img src="ext/diy-audio-player/images/pause32.png" />
      <img src="ext/diy-audio-player/images/pause32Highlight.png" />
      <img src="ext/diy-audio-player/images/play20Highlight.png" />
      <img src="ext/diy-audio-player/images/stop32.png" />
      <img src="ext/diy-audio-player/images/stop32Highlight.png" />
      <img src="ext/diy-audio-player/images/search20Highlight.png" />	
    </div>
  </xsl:template>


  <!-- *** -->
  <!-- * Workflow control -->
  <!-- *** -->

  <xsl:template name="workflow-block">
    <xsl:variable name="httpCollection">
      <xsl:value-of select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/>
    </xsl:variable>

    <div id="workflow-turnstyle">

      <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	Workflow
      </div>

      <div class="documenttext hide" style="color: white; background-color: rgb(40%,40%,20%); padding: 8px;">
	
<!--
	<form style="padding-left: 8px;">
	  <span class="vis-heading">Input Selection:</span>
	  <input type="radio" name="inputSelection" onclick="setInputSelectionMode(this)" value="left"/>Left only
	  <input type="radio" name="inputSelection" onclick="setInputSelectionMode(this)" value="right"/>Right only
	  <input type="radio" name="inputSelection" onclick="setInputSelectionMode(this)" value="diff"/>Average
	  <input type="radio" name="inputSelection" onclick="setInputSelectionMode(this)" value="mix" checked="checked"/>Difference
	</form>
	<hr/>
-->

	<form style="padding-left: 8px; height: 48px;">
	  <span class="vis-heading" style="padding-right: 10px" >Meandre Workflow:</span>

	  <select id="meandre-workflow-pos" onChange="loadSelectedWorkflow(this)" style="font-size: 90%; padding 8px;">
	    <option value="0" selected="selected">Chromagram</option>
	    <option value="1" >Dynamic Javascript Mixer</option>
	  </select>

	  <div style="float: right;" id="meandre-buttons">
	 
	    <button type="button" id="meandre-run-button"  
		    onclick="selectedMeandreWorkflow.runThisMeandreFlow(this)">
	      <img id="meandre-run-button" src="ext/diy-audio-player/images/play32.png" 
		   width="32"
		   height="32"  
		   XXonmouseover="playHighlightOn(this)"
		   XXonmouseout="playHighlightOff(this)"
		   XXonclick="runThisMeandreFlow(this)"
		   style="vertical-align: middle;"/>
	      Run
	    </button>

	    <button type="button" id="meandre-stop-button" onclick="selectedMeandreWorkflow.stopThisMeandreFlow(this)" disabled="disabled">
	      <img id="meandre-stop-button" src="ext/diy-audio-player/images/stop32.png" 
		   width="32"
		   height="32"  
		   XXonmouseover="stopHighlightOn(this)"
		   XXonmouseout="stopHighlightOff(this)"
		   XXonclick="stopThisMeandreFlow(this)"
		   style="vertical-align: middle;"/>
	      Stop
	    </button>

<!--
	    <button type="button" id="meandre-run-button" onclick="runThisMeandreFlow(this)" >Run</button>
	    <button type="button" id="meandre-stop-button" onclick="stopThisMeandreFlow(this)" disabled="disabled">Stop</button>
-->

	  </div>

	</form>

	<style>
	  #meandre-buttons button:hover:enabled {
	    background-color: #CCCC33;
	    color: #FFFFFF;
	  }
	</style>
	  

	<div style="position: relative;">
	  <iframe id="workbenchFrame" 
		  style="width: 100%; height: 400px;" >
	    If you see this, then your browser does not support the iframe element.
	  </iframe>

	</div>

	<gsf:script src="{$httpCollection}/script/meandre-workflow/chromagram.js"/>
	<gsf:script src="{$httpCollection}/script/meandre-workflow/js-dynamic-mix.js"/>
	
	<gsf:script>
	  var chromagramMeandreWorkflow = new ChromagramMeandreWorkflow();
	  var jsDynamicMixMeandreWorkflow = new JSDynamicMixMeandreWorkflow();

	  var meandreWorkflows = [ chromagramMeandreWorkflow, jsDynamicMixMeandreWorkflow ];

	  var selectedMeandreWorkflowPos =$('#meandre-workflow-pos option:selected').val();
	  var selectedMeandreWorkflow = meandreWorkflows[selectedMeandreWorkflowPos];

	  selectedMeandreWorkflow.meandreController.loadWorkbench( "workbenchFrame",selectedMeandreWorkflowPos);
	  
	  function loadSelectedWorkflow(elem) { 	       
	      selectedMeandreWorkflowPos = elem.value;
	      selectedMeandreWorkflow = meandreWorkflows[selectedMeandreWorkflowPos];

	    if (selectedMeandreWorkflowPos==1) {
	      $('#jsdynamic-turnstyle').show();
	    }
	    else {
	      $('#jsdynamic-turnstyle').hide();
	    }

	    console.info("Loading in new Meandre workbench flow (pos=" + selectedMeandreWorkflowPos+ ")");		
	    selectedMeandreWorkflow.meandreController.loadWorkbench("workbenchFrame",selectedMeandreWorkflowPos);

	  }
	</gsf:script>
	



	<div id="jsdynamic-turnstyle" style="display:none">
	  
	  <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	    Dynamic Javascript Meandre Component
	  </div>

	  <div class="documenttext hide" style="color: white; background-color: rgb(40%,40%,20%); padding: 8px;">

	    <textarea id="js-dynamic-code" style="width:100%; height: 520px; font-size: 60%">
	      <xsl:text disable-output-escaping="yes">


var arrayBinding = new JavaImporter(java.lang.reflect.Array);

var JSDynamicComponent = function() {
  this.frameCount = 0;
}

JSDynamicComponent.prototype.executeCallBack = function(cc) {

  with(arrayBinding) {

    if ((this.frameCount % 1000)==0) {
      print("JSDynamicComponent: " + this.frameCount + "\n");
    }

    var inputObject = cc.getDataComponentFromInput("input");
    var rawInput1DArray = inputObject;

    var rawOutput1DArray = Array.newInstance(java.lang.Double.TYPE, rawInput1DArray.length);

    for (var i=1; i&lt;rawOutput1DArray.length; i++) {
      var diff = Array.getDouble(rawInput1DArray,i) - Array.getDouble(rawInput1DArray, i-1);
      Array.setDouble(rawOutput1DArray,i,diff);
    }

    cc.pushDataComponentToOutput("output", rawOutput1DArray);

    this.frameCount++;
  }

}

var jsDynamicComponent = new JSDynamicComponent();

	      </xsl:text>
	    </textarea>
	  </div> <!-- end of Dynamic JS turnstyle block -->
	</div>

      </div>

    </div>

    <script>
      <xsl:text disable-output-escaping="yes">
	$(function(){
	    transformToTurnstyleBlock("workflow");
	    transformToTurnstyleBlock("jsdynamic");
	});	
      </xsl:text>
    </script>
  </xsl:template>


  <!-- *** -->
  <!-- * Structured audio player -->
  <!-- *** -->
 
  <xsl:template name="structuredAudioPlayerBlock">

    <gsf:script src="ext/diy-audio-player/script/structured-audio-play.js"/>
    
    <div style="background-color: rgb(40%,40%,20%)">
      <svg xmlns="http://www.w3.org/2000/svg" 
           xmlns:xlink="http://www.w3.org/1999/xlink" 
	   version="1.1"
           id="svgGroundTruthSegments" 
	   width="100%" height="24"
           onLoadXX="svgGTStructuredInit()">
      </svg>
    </div>
    
    <div style="background-color: rgb(40%,40%,20%)">
      <svg xmlns="http://www.w3.org/2000/svg" 
           xmlns:xlink="http://www.w3.org/1999/xlink" 
	   version="1.1"
           id="svgContentAnalysisSegments" 
	   width="100%" height="24"
           onLoadXX="svgCAStructuredInit({$cgiargCAAlgorithm})">
      </svg>
    </div>
  </xsl:template>
  
  <xsl:template name="visualization-mode-block">
    
    <div class="documenttext" style="color: white; background-color: rgb(40%,40%,20%); padding-top: 4px;">

      <span class="vis-heading">Max Values:</span>
      <div style="padding-left: 8px">
	<style>
	  span.mv-fixed { display: inline-block; width: 30pt; }
	</style>
	<table width="100%">
	  <tr>
	    <td><span class="mv-fixed" id="freqSpectrumMax"     >0.000</span>(Freq Spectrum)       </td>
	    <td><span class="mv-fixed" id="freqPowerSpectrumMax">0.000</span>(Freq Power Spectrum) </td>
	    <td><span class="mv-fixed" id="filterBankMax"       >0.000</span>(Filter Bank)         </td>
	    <td><span class="mv-fixed" id="chromaFeaturesMax"   >0.000</span>(Chroma Features)     </td>
	  </tr>
	</table>
      </div>
      <hr/>
  
      <form style="padding-left: 8px; padding-right: 8px; padding-bottom: 0px;">
	<div style="float: left;">
	  <span class="vis-heading">Visualization:</span>
<!--
	<input type="radio" name="visualization" onclick="setTransformMode(this)" value="freqSpectrum" />Frequency Spectrum 
	<input type="radio" name="visualization" onclick="setTransformMode(this)" value="freqPowerSpectrum"/>Frequency Power Spectrum
-->
	
	  <input type="radio" name="visualization" onclick="setTransformMode(this)" value="filterBank"/>Filter Bank 
	  <input type="radio" name="visualization" onclick="setTransformMode(this)" value="chromaFeatures" checked="checked"/>Chroma Features
	</div>

	<div style="float: left; padding-left: 140px;">
	  <span class="vis-heading">Colour Mapping:</span>
	  <input type="radio" name="colorMapping" onclick="setColorMappingMode(this)" value="rgb"/>RGB Intensity
	  <input type="radio" name="colorMapping" onclick="setColorMappingMode(this)" value="hsl" checked="checked"/>HSL Heat
	</div>
      </form>
      
      <div style="clear: both; padding-top: 4px; padding-bottom: 4px;"><hr/></div>

<!--
      <form style="padding-left: 8px;">
	<span class="vis-heading">Colour Mapping:</span>
	<input type="radio" name="colorMapping" onclick="setColorMappingMode(this)" value="rgb"/>RGB Intensity
	<input type="radio" name="colorMapping" onclick="setColorMappingMode(this)" value="hsl" checked="checked"/>HSL Heat Map
      </form>
      <hr/>
-->



	<form style="padding-left: 8px; padding-bottom: 0px;">
	  <div style="float: left;">
	    <input type="checkbox" name="similarityMatrix" onclick="plotSimilarityMatrixWhenPaused(this)"/>Show Similarity Matrix
	  </div>
	  <div style="float: left; padding-left: 140px;">
	    <span class="vis-heading">Accelerated  Processing:</span>
	    <input type="checkbox" name="acceleratedProcessingInput" onclick="acceleratedProcessingCheckbox(this)"/>&gt; realtime
	    <span id="accProcStatus"></span>
	  </div>

	</form>
	<div style="clear: both; padding-top: 4px; padding-bottom: 4px;"><hr/></div>

	<hr/>

    </div>
    
    <xsl:call-template name="graphic-equalizers"/>
  </xsl:template>


  <xsl:template name="graphic-equalizers">


    <gsf:style >
      #grapheqControlL {
        display: none;
      }

      #grapheqControlR {
        display: none;
      }

      .control {
        padding: 5px;
        border: 1px solid #CCC;
        background-color: #EEE;
        float: left;
        margin-right: 5px;

      }

      .inner-control {
        background-color: #DDD;
      }

      .control div {
	max-width: 400px;
      }

      .control table td {
        padding: 5px;
        width: 25px;
        color: #999;
        font-size: 12px;
      }
      .control h3 {
        margin: 0;
        padding:0;
        font-size: 12px;
        margin-bottom: 10px;
      }
      .control #debug {
        border: 1px inset #ccc;
        background-color: #FFF;
        font-size: 12px;
        width: 300px;
        padding: 10px;
      }
      .slider {
        margin-bottom: 16px;
        width: 8px;
      }
/*
      .geq-bar {
        width: 34px;
      }
*/

/*
      .ui-button {
        font-size: xx-small;
      }
*/
      .ui-slider .ui-slider-handle {
        width: 8px;
        margin-left: 3px;
      }
    </gsf:style>



   <gsf:script>
      <![CDATA[

        var grapheqL;
        var grapheqR;

      $(function() {
        var geqSampleRate = 44100;
        console.log("*** hardwiring Graphic Equalizer sampleRate to be: " + geqSampleRate);

        grapheqL = new GraphicalEq(geqSampleRate);
        grapheqR = new GraphicalEq(geqSampleRate);
        grapheqL.recalculateFilters();
        grapheqR.recalculateFilters();

        var minPropL = { orientation: 'vertical', range: 'min', min: 10, max: 22000, step: 1, value: 40, 
	                 slide: function() { changeMinFreq(grapheqL,"L")} };
        var minPropR = { orientation: 'vertical', range: 'min', min: 10, max: 22000, step: 1, value: 40, 
	                 slide: function() { changeMinFreq(grapheqR,"R")} };

	var maxPropL = { orientation: 'vertical', range: 'min', min: 10, max: 22000, step: 1, value: 16000, 
	                 slide: function() { changeMaxFreq(grapheqL,"L") } };
	var maxPropR = { orientation: 'vertical', range: 'min', min: 10, max: 22000, step: 1, value: 16000, 
	                 slide: function() { changeMaxFreq(grapheqR,"R") } };

        var bpoPropL = { orientation: 'vertical', range: 'min', min: 0.1, max: 2, step: 0.1, value: 1, 
	                 slide: function() { changeBandsPerOctave(grapheqL,"L")} };
        var bpoPropR = { orientation: 'vertical', range: 'min', min: 0.1, max: 2, step: 0.1, value: 1, 
	                 slide: function() { changeBandsPerOctave(grapheqR,"R")} };

        $('#minFreqL').slider(minPropL);
        $('#maxFreqL').slider(maxPropL);
        $('#minFreqR').slider(minPropR);
        $('#maxFreqR').slider(maxPropR);

        $('#bandsPerOctaveL').slider(bpoPropL);
        $('#bandsPerOctaveR').slider(bpoPropR);

	//$('#input').attr('volume', 0);

	createSliders(grapheqL,"L");
	createSliders(grapheqR,"R");
      });



      var changeMinFreq = function(grapheq,side) {
         grapheq.setMinimumFrequency($('#minFreq'+side).slider('option', 'value'));
         //plotCoeffs();
	 createSliders(grapheq,side);
      }

      var changeMaxFreq = function(grapheq,side) {
         grapheq.setMaximumFrequency($('#maxFreq'+side).slider('option', 'value'));
         //plotCoeffs();
	 createSliders(grapheq,side);
      }

      var changeBandsPerOctave = function(grapheq,side) {
         grapheq.setBandsPerOctave($('#bandsPerOctave'+side).slider('option', 'value'));
         //plotCoeffs();
	 createSliders(grapheq,side);
      }

	function positionGrapheqControl(grapheq,side) {

	    var numSliders = grapheq.filters.length;
            var offset = (35 * numSliders) + 12;
	    if (side == "L") {
	        offset += 30; // fudge factor
	        $('#grapheqControlL').css("left","-" + offset + "px");
	    }
	    else if (side == "R") {
	        offset += 35; // fudge factor, used to be 5
	        $('#grapheqControlR').css("right","-" + offset + "px");
	    }
	    else {
	        console.error("positionGrapheqControl(): unrecognized side '" + side + "'");
	    }
	}

      var createSliders = function(grapheq,side) {
	$('#bandSliders'+side).empty();
	positionGrapheqControl(grapheq,side);
	for (var i=0; i<grapheq.filters.length; i++) {
	
	  var freq = grapheq.filters[i].f0;
	  var units = "Hz";
	  if (freq>=1000000) {
	    freq = (freq/1000000).toFixed(2);
	    units = " MHz";
	  }
	  else if (freq>=1000) {
	    freq = (freq/1000).toFixed(2);
	    units = " KHz";
	  }
	  else if (freq>=100) {
	    freq = freq.toFixed(0);
	  }
	  else {
	    freq = freq.toFixed(0);
	    freq = "&nbsp;" + freq;
	  }

	  $('#bandSliders'+side).append('<td class="geq-bar"><div id="band'+side+'_'+i+'" class="slider"></div>'
	      +freq + ' ' + units + '</td>');

	  $('#band'+side+'_'+i).slider({ orientation: 'vertical', range: 'min', min: -10, max: 3, step: 0.1, value: 0, 
	                                 slide: function(event,ui) { changeBandGain(event,ui,grapheq)} });
	}
      }
      
      var changeBandGain = function(event, ui, grapheq) {
	grapheq.setBandGain(ui.handle.parentNode.id.split("_")[1], ui.value);
        //plotCoeffs();
      }
/*
      var plotCoeffs = function() {
	freqz = new Float32Array(grapheq.freqzs[0].length);

	for (var i=0; i<freqz.length; i++) {
	  for (var j=0; j<grapheq.freqzs.length; j++) {
	    freqz[i] += grapheq.freqzs[j][i];
	  }
	}
      }
*/

/*
      function audioWritten(event) {
        signal = event.mozFrameBuffer;

        // Apply the filter to the signal
        signal = grapheq.processStereo(signal);

        output.mozWriteAudio([]); // flush
        output.mozWriteAudio(signal);
        writeCount++;
      }
*/

        //plotCoeffs();


      ]]>
    </gsf:script>


      <gsf:script>
	function minimizeTurnstyle(suffix) {
	  $('#turnstyleMaximizeButton'+suffix).show();
	  $('#turnstyleMinimizeButton'+suffix).hide();
	  $('#turnstyleContentsArea'+suffix).slideUp('fast');
       }

	function maximizeTurnstyle(suffix) {
	  $('#turnstyleMaximizeButton'+suffix).hide();
	  $('#turnstyleMinimizeButton'+suffix).show();
	  $('#turnstyleContentsArea'+suffix).slideDown('fast');
       }

      </gsf:script>

<!--    
    <div class="control" style="float: left; height: 200px">
-->


    <div id="grapheqControlL" class="control" style="position: absolute; top: 280px; left: -132px; heightXX: 200px">

      <h3 style="float: left;">Graphic Equalizer (left channel)</h3>
      <div style="float: right;">
	<span style="font-size: 75%; padding-right: 5px;">(advanced)</span>
	<a id="turnstyleMinimizeButtonL" style="float: right; font-size: 0.6em; display: none;" href="javascript:minimizeTurnstyle('L');">
	  <img class="icon" style="padding-top:3px;" src="interfaces/{$interface_name}/images/collapse.png"/>
	</a>
	<a id="turnstyleMaximizeButtonL" style="float: right; font-size: 0.6em; display: block;" href="javascript:maximizeTurnstyle('L');">
	  <img style="padding-top:3px;" src="interfaces/{$interface_name}/images/expand.png" class="icon"/>
	</a>
      </div>

      <hr style="clear: both;"/>

      <div id="turnstyleContentsAreaL" style="display: none; float: right;">

	<table class="inner-control" style="margin-bottom: 5px;">
	  <tr>
	    <td><div id="minFreqL" class="slider"><xsl:comment/></div>Min Freq</td>
	    <td><div id="maxFreqL" class="slider"><xsl:comment/></div>Max Freq</td>
	    <td><div id="bandsPerOctaveL" class="slider"><xsl:comment/></div>Bands/ Octave</td>
	  </tr>
	</table>
      </div>

      <div style="clear: both; height: 0px;"><xsl:comment></xsl:comment></div>
	
      <table class="inner-control"> 
	<tr id="bandSlidersL">
	</tr>
      </table>



    </div>

<!--
    <div class="control" style="float: right; height: 200px">
-->

    <div id="grapheqControlR" class="control" style="position: absolute; top: 280px; right: -330px; heightXX: 200px">
      <h3 style="float: left;">Graphic Equalizer (right channel)</h3>

      <div style="float: right;">
	<span style="font-size: 75%; padding-right: 5px;">(advanced)</span>
	<a id="turnstyleMinimizeButtonR" style="float: right; font-size: 0.6em; display: none;" href="javascript:minimizeTurnstyle('R');">
	  <img class="icon" style="padding-top:3px;" src="interfaces/{$interface_name}/images/collapse.png"/>
	</a>
	<a id="turnstyleMaximizeButtonR" style="float: right; font-size: 0.6em; display: block;" href="javascript:maximizeTurnstyle('R');">
	  <img style="padding-top:3px;" src="interfaces/{$interface_name}/images/expand.png" class="icon"/>
	</a>
      </div>

      <hr style="clear: both;"/>

      <div id="turnstyleContentsAreaR" style="display: none; float: left;">
	<table class="inner-control" style="margin-bottom: 5px;">
	  <tr>
	    <td><div id="minFreqR" class="slider"><xsl:comment/></div>Min Freq</td>
	    <td><div id="maxFreqR" class="slider"><xsl:comment/></div>Max Freq</td>
	    <td><div id="bandsPerOctaveR" class="slider"><xsl:comment/></div>Bands/ Octave</td>
	  </tr>
	</table>
      </div>

      <div style="clear: both; height: 0px;"><xsl:comment></xsl:comment></div>

      <table class="inner-control"> 
	<tr id="bandSlidersR">
	</tr>
      </table>

    </div>
    
  </xsl:template>


  <!-- *** -->
  <!-- * Settings form -->
  <!-- *** -->

  <xsl:template name="settings-form">
    <xsl:param name="cgiargYScaleSimImg"/>

    <xsl:variable name="httpCollection">
      <xsl:value-of select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/>
    </xsl:variable>

<!--
    <gsf:variable-array name="overlayNote2">
      <gsf:metadata multiple="true" name="salami.overlayNote" separator=", "/>
    </gsf:variable-array>

    <span id="overlayNewNotes2" class="ui-state-default ui-corner-top" style="font-size:90%; padding: 3px; cursor:pointer;">
      New Annotation 2
    </span>	  

    <div id="noteOverlay2" style="width: 100%; height: 300px; background-color: #cccccc;">
    </div>

    <gsf:script>
      $(window).load(function(){ 
           var overlayNotes2 = new OverlayNotes("noteOverlay2","salami.overlayNote");
	   $('#overlayNewNotes2').click(function() {overlayNotes2.AddNote() });
       });

    </gsf:script>
-->

    <div style="display: none;"><!-- wrapped div to force display to none -->

    <div id="settings-turnstyle" style="margin: 6px;">
      <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	Audio Content Search
      </div>
      <div class="documenttext" style="display: none;">


      <form id="QueryForm" name="QueryForm" method="get" action="{$library_name}">
	<input type="hidden" name="a" value="q"/>
	<input type="hidden" name="sa"><xsl:attribute name="value"><xsl:value-of select="/page/pageRequest/@subaction"/></xsl:attribute></input>
	<input type="hidden" name="rt" value="rd"/>
	
	<input type="hidden" name="s" value="AudioQuery"/>
	<input type="hidden" name="c" value="{$collName}"/>
	<xsl:if test="not(paramList/param[@name='startPage'])">
	  <input type="hidden" name="startPage" value="1"/>
	</xsl:if>
	<xsl:choose>
	  <xsl:when test="/page/pageRequest/paramList/param[@name = 's1.maxDocs']">
	    <input type="hidden" name="s1.maxDocs">
	      <xsl:attribute name="value">
		<xsl:value-of select="/page/pageRequest/paramList/param[@name = 's1.maxDocs']/@value"/>
	      </xsl:attribute>
	    </input>
	  </xsl:when>
	  <xsl:otherwise>
	    <input type="hidden" name="s1.maxDocs" value="100"/>
	  </xsl:otherwise>
	</xsl:choose>
	<xsl:choose>
	  <xsl:when test="/page/pageRequest/paramList/param[@name = 's1.hitsPerPage']">
	    <input type="hidden" name="s1.hitsPerPage">
	      <xsl:attribute name="value">
		<xsl:value-of select="/page/pageRequest/paramList/param[@name = 's1.hitsPerPage']/@value"/>
	      </xsl:attribute>
	    </input>
	  </xsl:when>
	  <xsl:otherwise>
	    <input type="hidden" name="s1.hitsPerPage" value="20"/>
	  </xsl:otherwise>
	</xsl:choose>
	
	<input type="hidden" name="q">
	  <xsl:attribute name="value"><xsl:value-of select="/page/pageResponse/document/documentNode/@nodeID"/>.dir</xsl:attribute>
	</input>
	
	
	<input type="hidden" name="s1.query">
<!--
	  <xsl:attribute name="value"><xsl:value-of select="/page/pageResponse/document/documentNode/@nodeID"/>.dir</xsl:attribute>
-->
	  <xsl:attribute name="value"><xsl:value-of select="/page/pageResponse/document/@nodeID"/>.dir</xsl:attribute>
	</input>
	
	<input type="hidden" name="s1.offset" value="0" />
	<input type="hidden" name="s1.length" value="200" />
	
	<div style="font-style: italics;">Start new query @ offset
	<span id="mysongCurrentPos">0 secs</span>,
	with excerpt lasting
	
	<input type="text" name="mysongWindowDuration" size="4" value="6" />
	<!--
	    <span id="mysongWindowDuration" class="editable-offset"
	    style="cursor: pointer; border: 1px solid black; padding: 3px; width: 200px; min-width: 200px;">6.0</span> 
	-->
	secs:

	<input type="submit" value="Search" onclick="preSubmit(this.form);" />
	</div>

	
	<ul style="font-size: 80%; margin-top: 8px; font-style: italics;" >
	  <li>Use the <b>Play all of</b> bar to get to the part of the song you are interested in.</li>
	  <li>... the <b>query @ offset</b> value will change accordingly as the song progresses.</li>
	  <li>Click <b>pause</b> (anywhere outside of the time-line) to mark the spot you want to start the new music query.</li>
	  <li>Optionally click on the <b>excerpt lasting</b> value and edit, if you want to change the length of excerpt used in the match.</li>
	  <li>Finally, click the <b>Search</b> button to initiate the new query.</li>
	</ul>
	
      </form>

      <hr/>
      
<!--
      <form id="RescaleForm" name="RescaleForm" method="get" action="{$library_name}">
	<div style="font-style: italics;">
	  Make the scale factor for the y-dimension of the self-similarity
	  image be
	  <input type="text" name="ResizeScale" value="{$cgiargYScaleSimImg}"
	         size="3" /> then 
	  <input type="button" name="ResizeImage" value="Resize Image" 
	         onclick="javascript:rescaleImage()" />
	  
	</div>
      </form>
      
      <hr/>
-->

      <!-- **** currently not displayed -->

      <form id="UpdateCAForm" name="UpdateCAForm" method="get" action="{$library_name}" style="display: none;">
	<div style="font-style: italics;">
	  
	  Show the song structure automatically computed by analyzing
	  the audio data using algorithm 

	  <select id="caaMenu" name="caAlgorithm">
	    <option value="1">BV1</option>
	    <option value="2">BV2</option>
	    <option value="3">GP7</option>
	    <option value="4">MHRAG2</option>
	    <option value="5">MND1</option>
	    <option value="6">WB1</option>

<!--
	    <option value="-1">or hide</option>
-->

	  </select>: 

	  <input type="button" name="Reload" value="Reload" 
	         onclick="updateCAAlgorithm()" />

	</div>
      </form>

	<script>
	  <xsl:text disable-output-escaping="yes"> 
	    if (hasStructuredAudio) {
	      var caaMenu = document.getElementById("caaMenu");
               caaMenu.options[caAlgorithm-1].selected = 1;
	    }
	  </xsl:text>
	</script>
      

      </div>
    </div>
    <script>
      <xsl:text disable-output-escaping="yes">
	$(function(){
	transformToTurnstyleBlock("settings");
	});
      </xsl:text>
    </script>

    </div><!-- wrapped div to force display to none -->

  </xsl:template>


  <!-- *** -->
  <!-- * Computed Data -->
  <!-- *** -->


  <xsl:template name="computed-data">
    <xsl:param name="httpCollection"/>
    <xsl:param name="assocFilePath"/>

    <div id="computed-turnstyle" style="margin: 6px;">
      <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	Computed Data
      </div>

      <div class="documenttext" style="display: none;">
	<table class="metadata-stripes" style="width: 100%">
	  <tbody>
	    <tr>
	      <td>jAudio Features</td><td><a href="{$httpCollection}/index/assoc/{$assocFilePath}/jaudio.xml">download ACE XML feature values file</a></td>
	    </tr>
	    
	    <tr>
	      <td>jSongMiner Metadata</td><td><a href="{$httpCollection}/index/assoc/{$assocFilePath}/jsongminer.xml">download ACE XML classifications file</a></td>
	    </tr>
	    
	  </tbody>
	</table>
      </div>
    </div>

    <gsf:script>
	$(function(){
	  transformToTurnstyleBlock("computed");
	});
    </gsf:script>

  </xsl:template>



  <xsl:template name="original-audio">
    <xsl:param name="httpCollection"/>
    <xsl:param name="assocFilePath"/>
    <xsl:param name="Audio"/>
    <xsl:param name="streamableaudio"/>

    <div id="original-turnstyle" style="margin: 6px;">
      <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	The Original Audio
      </div>

      <div style="display: none;">

	<div>
	  <audio style="width: 100%;" id="original-audio" controls="controls" >
<!--
	    <source src="{$httpCollection}/index/assoc/{$assocFilePath}/doc.ogg" />
-->
	    <source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$streamableaudio}" />
	    <source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$Audio}" />
	  </audio>
	</div>

      </div>
    </div>

    <gsf:script>
	$(function(){
	  transformToTurnstyleBlock("original");
	});
    </gsf:script>



  </xsl:template>


  <xsl:template name="documentContent">
<!--
<xsl:call-template name="init-document-xsl-vars"/>
-->
<!--
declare $httpCollection = $httpPath (for better consistency with other places in Greenstone XSL files)
-->

    <xsl:variable name="httpCollection">
      <xsl:value-of select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/>
    </xsl:variable>
    <xsl:variable name="assocFilePath">
      <gsf:metadata name="assocfilepath" select="root"/>
    </xsl:variable>
    <xsl:variable name="Source">
      <gsf:metadata name="Source" select="root"/>
    </xsl:variable>
    <xsl:variable name="Audio">
      <gsf:switch>
	<gsf:metadata name="Audio" select="root"/>
	<gsf:when test="exists">
	  <gsf:metadata name="Audio" select="root"/>
	</gsf:when>
	<gsf:otherwise>doc.ogg</gsf:otherwise>
      </gsf:switch>
    </xsl:variable>
    <xsl:variable name="streamableaudio">
      <gsf:switch>
	<gsf:metadata name="streamableaudio" select="root"/>
	<gsf:when test="exists">
	  <gsf:metadata name="streamableaudio" select="root"/>
	</gsf:when>
	<gsf:otherwise>doc.mp3</gsf:otherwise>
      </gsf:switch>
    </xsl:variable>
    
    <xsl:variable name="streamablevideo">
      <gsf:metadata name="SourceFile"/>
    </xsl:variable>
    
    <div class="documenttext" id="gs-document">

<div>


  <div id='media-player' style="width: 96%">

    <xsl:if test="$interface_name='dlfm'">
      <style>
	.openclose a:visited {
        color: #ffffff;
	}
	.openclose a:link {
        color: #ffffff;
	}
	.openclose a:hover { 
  	  color: #000000; 
	}

      </style>
    </xsl:if>

    <div class="about-bar">
      <div id="about-titlebar" style="background-image: none; background-color: #2E52A4; width: 97%; float: left; margin-bottom: 10px; z-index: 4; position: relative;">

	<xsl:choose>
          <xsl:when test="$interface_name='dlfm'">
	    Linked Data: <xsl:call-template name="choose-title"/>
	  </xsl:when>
	  <xsl:otherwise>
	    About: <xsl:call-template name="choose-title"/>
	  </xsl:otherwise>
	</xsl:choose>
      </div>

      <div style="clear: both;"><xsl:comment>clear floats</xsl:comment></div>

      <div id="about-area" class="documenttext" 
	   style="display: none; position: absolute: left: 0px; top: 0px; z-index: 1;">
	<xsl:call-template name="fingerprintMetadataBlock" />
      </div>
    </div>

    <div class="video-player-bar">
      <div id="video-titlebar" style="background-image: none; background-color: #2E52A4; width: 97%; float: left; margin-bottom: 10px; z-index: 4; position: relative;">
	Video Display
      </div>

      <div id="video-area" class="documenttext" 
	   style="display: none; position: absolute: left: 0px; top: 0px; z-index: 1;">
	<center>


	  <style>
	    #video_box {position:relative; z-index: 1;}
	    #overlay {position: absolute; t: 0; left: 0; z-index: 2;}
	    #video_container {z-index: 1;}

	    #XXXvideo_container {position:absolute;top: 0px;left: 0px;}
	  </style>


	  <div id="video_box">
	    <div id="overlay"><xsl:comment>filler</xsl:comment></div>
	    <div id="video_container">

	      <video id="video" width="60%" controls="false">
		<source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$streamablevideo}" />
		<track id="bubbles" label="Metadata" kind="metadata" 
		       srclang="en" src="{$httpCollection}/tracks/land-down-under-metadata-en.vtt" default="default" />
		Your browser does not support the video tag.
	      </video>

	    </div>
	  </div>
	</center> 
      </div>
    </div>

    <div id='media-controls'>
      <div>
	<input id="progress-bar" type="range" 
	       min='0' max='100' step='0.01' value='0' 
	       class="ui-state-default ui-corner-all"
	       style="width: 98%"/> <!-- used to be 100% -->

      </div>
      <div style="width: 100%;">
	<div style="float:left; padding: 8px; ">
	  <button id='replay-button'     class='buttonx2 replay' title='replay' onclick='replayMedia();'>Replay</button>	
	  <button id='play-pause-button' class='buttonx2 play' title='play/pause (or press space-bar on keyboard)' onclick='togglePlayPause();'>Play</button>
	  <button id='stop-button'       class='buttonx2 stop' title='stop' onclick='stopPlayer();'>Stop</button>
	</div>
	<div style="float:right; padding: 8px; ">
	  <div style="display: inline; font-family: Arial,Helvetica,sans-serif; color: white">
	    <span id="mediaPlayerCurrentTime">0:00.0</span>/
	    <span id="mediaPlayerTotalTime">0:00.0</span>
	  </div>
	  <button id="eq-button" class="button" title="Show/Hide graphics equalilzer" onclick="return toggleGraphicEQ()">EQ</button>
	  <button id='volume-dec-button' class='button volume-minus' title='decrease volume' onclick="changeVolume('-');">Decrease volume</button>
	  <button id='volume-inc-button' class='button volume-plus' title='increase volume' onclick="changeVolume('+');">Increase volume</button>
	  <button id='mute-button'       class='button mute' title='mute' onclick="toggleMute('true');">Mute</button>	
	</div>
      </div>
    </div>


    <div style="clear: both;"><xsl:comment>clear floats</xsl:comment></div>

    <xsl:call-template name="graphic-equalizers"/>

    <div style="clear: both;"><xsl:comment>clear floats</xsl:comment></div>

    <div class="playlist-bar">
      <div id="playlist-titlebar" style="background-image: none; background-color: #2E52A4; width: 97%; float: left; margin-bottom: 10px;">
	Layer Controls: Create, Edit, View
      </div>

      <div style="clear: both;"><xsl:comment>clear floats</xsl:comment></div>

      <div id="playlist-area" class="documenttext" 
	   style="display: none; position: absolute: left: 0px; top: 0px;">
<!--
	<div id='media-play-list'>
	  <h2>Play list</h2>
	  <ul id='play-list'>
	    <li><span class='play-item' onclick="loadVideo('parrots.webm', 'parrots.mp4');">Parrots</span></li>
	    <li><span class='play-item' onclick="loadVideo('paddle-wheel.webm', 'paddle-wheel.mp4');">Paddle Steamer Wheel</span></li>
	    <li><span class='play-item' onclick="loadVideo('grass.webm', 'grass.mp4');">Grass</span></li>
	  </ul>
	</div>
-->

         <div id="save-recording-popup" title="Save Recording">
	   <p>Do you want to name and save this recording?</p>
 
	   <form>
	     <fieldset>
	       <label for="name">Name</label>
	       <input type="text" 
		      name="save-recording-name" id="save-recording-name" value="My Recording" 
		      class="text ui-widget-content ui-corner-all"/>	       
	     </fieldset>

	       <!-- Allow form submission with keyboard without duplicating the dialog button -->
	       <input type="submit" tabindex="-1" style="position:absolute; top:-1000px"/>

	   </form>
	 </div>

         <div id="delete-recording-popup" title="Delete Tracks">
	   <p>Are you sure you want to delete the selected tracks?</p>
 	 </div>


         <div id="edit-recording-popup" title="Edit Tracks">
	   <style>
	     #trackEditor {
	       position: absolute;
	       top: 0; right: 0; bottom: 0; left: 0;
	     }
	   </style>
	   <div id="trackEditor"><xsl:comment>Track Editor Area</xsl:comment></div>
 	 </div>



          <div style="color: white;">

	    <form id="bubForm" style="width: 99%; margin-top: 10px; margin-bottom: 10px;">
	      <fieldset>
		<legend id="mpm-legend">Popup Layers</legend>
		<input type="checkbox" name="PopupTrivia" value="PopupTrivia" />Popup Trivia<br />
		<input type="checkbox" name="Lyrics" value="Lyrics" />Lyrics<br />
		<input type="checkbox" name="MisheardLyrics" value="MisheardLyrics" />Misheard Lyrics<br />
		<input type="checkbox" name="GuitarChords" value="GuitarChords" />Play-along Guitar Chords<br />
		
		<div style="padding: 8px;">
		  <button id="mpm-new-overlay" 
			  classXX="ui-button ui-widget ui-state-default ui-corner-all ui-button-text-icon-primary"
			  style="background-color:#2E52A4; color:#CCC; width:19%; text-align: center; margin-right: 8px;">
		    New Layer
		  </button>
		  <button id="mpm-merge-overlay" 
			  classXX="ui-button ui-widget ui-state-default ui-corner-all ui-button-text-icon-primary"
			  style="background-color:#2E52A4; color:#CCC; width:19%; text-align: center; margin-right: 8px;">
		    Merge Selected
		  </button>
		  <button id="mpm-split-overlay" 
			  classXX="ui-button ui-widget ui-state-default ui-corner-all ui-button-text-icon-primary"
			  style="background-color:#2E52A4; color:#CCC; width:19%; text-align: center; margin-right: 8px;">
		    Split Selected
		  </button>
		  <button id="mpm-edit-overlay"  
			  classXX="ui-button ui-widget ui-state-default ui-corner-all ui-button-text-icon-primary"
			  style="background-color:#2E52A4; color:#CCC; width:19%; text-align: center; margin-right: 8px;">
		  Edit Selected
		  </button>
		  <button id="mpm-delete-overlay"  
			  classXX="ui-button ui-widget ui-state-default ui-corner-all ui-button-text-icon-primary"
			  style="background-color:#2E52A4; color:#CCC; width:19%; text-align: center;">
		  Delete Selected
		  </button>
		</div>
	      </fieldset>
	    </form>

	    <form id="mpmForm" style="width:99%;">
	      <fieldset>
		<legend id="mpm-legend">Video Player Mode</legend>
		
		<div id="mpm-div" class="radio-div">

		  <div class="radio-label-combo" style="display:inline-block; width: 32%">
		    <span>
		      <input type="radio" id="mpm-record" name="mpm-radio" onchange="setPlaybackMode()" value="record"/>
		    </span>
		    <label for="mpm-record" class="radio-label">
		      <span style="color: red;" title="The notes/beat you play on the instruments get recorded, and form a new layer">
			Lay down new track
		      </span>
		    </label>
		  </div>

		  <div class="radio-label-combo" style="display:inline-block; width: 32%">
		    <span>
		      <input type="radio" id="mpm-neutral" name="mpm-radio" onchange="setPlaybackMode()" value="neutral" checked="checked"/>
		    </span>
		    <label for="mpm-neutral" class="radio-label">
		      <span style="color: orange;" title="Sit back and relax listening to the video">
			Put into Neutral
		      </span>
		    </label>
		  </div>

		  <div class="radio-label-combo" style="display:inline-block; width: 32%">
		    <span>
		      <input type="radio" id="mpm-game-on" name="mpm-radio" onchange="setPlaybackMode()" value="overlay"/>
		    </span>
		    <label for="mpm-game-on" class="radio-label">
		      <span style="color: green;" title="When you play the video, try to play one of the instruments below to match the notes in the chosen layers on display.  Get it right, and a rich rendition of the pop song is played, otherwise it sounds quite and tinny">
			Game on!
		      </span>
		    </label>
		  </div>

		</div>
	      </fieldset>
	    </form>


	    <form id="palForm" style="width: 99%; margin-top: 10px; margin-bottom: 10px; ">
	      <fieldset>
		<legend id="pal-legend">Play Along Layers: Game On!</legend>
		<div id="palList"><xsl:comment>play along list</xsl:comment></div>
		
		<div style="padding: 8px;">
		  <button id="pal-display-overlay" 
			  style="background-color:#2E52A4; color:#CCC; width:19%; text-align: center; margin-right: 2px;"
			  onclick="return palDisplay()">
		    Display Selected
		  </button>
		  <button id="pal-merge-overlay"   
			  style="background-color:#2E52A4; color:#CCC; width:19%; text-align: center; margin-right: 2px;">
		    Merge Selected
		  </button>
		  <button id="pal-split-overlay"   
			  style="background-color:#2E52A4; color:#CCC; width:19%; text-align: center; margin-right: 2px;">
		    Split Selected
		  </button>
		  <button id="pal-edit-overlay"    
			  style="background-color:#2E52A4; color:#CCC; width:19%; text-align: center; margin-right: 2px;"
			  onclick="return palEdit()">
		  Edit Selected
		  </button>
		  <button id="pal-delete-overlay"  
			  style="background-color:#2E52A4; color:#CCC; width:19%; text-align: center;"
			  onclick="return palDelete()">
		  Delete Selected
		  </button>
		</div>
	      </fieldset>
	    </form>


	  </div>

	</div>
    </div>


    <div style="clear: both;"><xsl:comment>clear floats</xsl:comment></div>

    <div class="analysis-bar">
      <div id="analysis-titlebar" style="background-image: none; background-color: #2E52A4; width: 97%; float: left; margin-bottom: 10px;">

	<xsl:choose>
          <xsl:when test="$interface_name='dlfm'">
	    Music Notes Visualizer
	  </xsl:when>
	  <xsl:otherwise>
	    Game On
	  </xsl:otherwise>
	</xsl:choose>
      </div>

      <div id="analysis-area" class="documenttext" 
	   style="display: none; position: absolute: left: 0px; top: 0px;">
	<div style="width:97.7%; height: 500px; margin: 6px; background-colorXX: white">
	  <div id="gameOnPaper" width="100%" height="445"><xsl:comment>filler</xsl:comment></div>
<!--
	  <svg id="gameOnPaper" xmlns="http://www.w3.org/2000/svg" version="1.1"
	       width="100%" height="445"
	       XXviewBox="0 0 100 100" XXpreserveAspectRatio="xMidYMid slice"
	       XXstyle="width:100%; height:100%;" styleXX="position:absolute; top:0; left:0; z-index:-1;">

	    <rect x="0" y="0" width="100" height="100" style="fill:rgb(0,0,255);stroke-width:1;stroke:rgb(0,0,0)" />
	    <xsl:comment>filler</xsl:comment>
	  </svg>
-->
	</div>
	  
      </div>
    </div>


    <div style="clear: both;"><xsl:comment>clear floats</xsl:comment></div>

    <div class="turnstyle-bar">

      <div id="piano-titlebar" 
	   style="background-image: none; background-color: #2E52A4; width: 30%; float: left; margin-right: 14px;">
	Piano
      </div>

      <div id="drumkit-titlebar" 
	   style="background-image: none; background-color: #2E52A4; width: 30%; float: left; margin-right: 14px;">
	Drums
      </div>

      <div id="guitar-titlebar" style="background-image: none; background-color: #2E52A4; width: 30%; float: left;">
	Guitar
      </div>


      <div style="clear: both;"><xsl:comment>clear floats</xsl:comment></div>

      <div style="position: relative;">

	<div id="piano-area" class="documenttext" style="display: none; position: absolute: left: 0px; top: 0px;">
	  <div id='jquery-piano'>
	    <div ID="keyboard" class="keyboard-holder"><xsl:comment>div for piano keyboard</xsl:comment></div>

	    <div class="keyboard-options" style="color: white">

	      <div style="float: left;">
		General Midi:
		<select ID="midi-sound" onchange="changeGMInstrument(this[selectedIndex].value)">
		  <option value="0" selected="selected">Acoustic Grand Piano</option>
		  <option value="19">Church Organ</option>
		  <option value="24">Acoustic Guitar Nylon</option>
		  <option value="30">Distortion Guitar</option>
		</select>
	      </div>

	      <div style="float: left;">
		Range [C<span ID="OCTAVE_LOWER">3</span>-B<span ID="OCTAVE_UPPER">5</span>]
		<input type="button" ID="-_OCTAVE" value="-" />
		<input type="button" ID="+_OCTAVE" value="+" /><br />
		<i>(Use left/right arrows to adjust with keyboard)</i>
	      </div>

	      <div style="clear: both;"><xsl:comment>clear floats</xsl:comment></div>

<!--	    
	    Sound
	    <select ID="sound">
	      <option value="0" selected="selected">Keyboard</option>
	      <option value="1" selected="selected">Organ</option>
	      <option value="2">Acoustic Guitar</option>
	      <option value="3">EDM, bro!</option>
	    </select>
-->
	    </div>


	  </div>
	  
	</div>

	<style>
	  .drumcontainer {
	    position: absolute;
	    top: 50%;
	    left: 50%;
	    transform: translateX(-50%) translateY(-50%);
	    -webkit-transform: translateX(-50%) translateY(-50%);
	    font-size: 100%;
	    color: #888888;
	    pointer-events: none;
	  }

.drum.hit {
  animation: drumHit .15s linear infinite;
  -webkit-animation: drumHit .15s linear infinite;
  -moz-animation: drumHit .15s linear infinite;
  -ms-animation: drumHit .15s linear infinite;
  -o-animation: drumHit .15s linear infinite;
}

@keyframes: drumHit; {
  0%   { background-size: 100%;}
  10%  { background-size: 95%; }
  30%  { background-size: 97%; }
  50%  { background-size: 100%;}
  60%  { background-size: 98%; }
  70%  { background-size: 100%;}
  80%  { background-size: 99%; }
  100% { background-size: 100%;}
}

@-webkit-keyframes drumHit {
  0%   { background-size: 100%;}
  10%  { background-size: 95%; }
  30%  { background-size: 97%; }
  50%  { background-size: 100%;}
  60%  { background-size: 98%; }
  70%  { background-size: 100%;}
  80%  { background-size: 99%; }
  100% { background-size: 100%;}
}

@-moz-keyframes drumHit {
  0%   { background-size: 100%;}
  10%  { background-size: 95%; }
  30%  { background-size: 97%; }
  50%  { background-size: 100%;}
  60%  { background-size: 98%; }
  70%  { background-size: 100%;}
  80%  { background-size: 99%; }
  100% { background-size: 100%;}
}

@-o-keyframes drumHit {
  0%   { background-size: 100%;}
  10%  { background-size: 95%; }
  30%  { background-size: 97%; }
  50%  { background-size: 100%;}
  60%  { background-size: 98%; }
  70%  { background-size: 100%;}
  80%  { background-size: 99%; }
  100% { background-size: 100%;}
}

@-ms-keyframes drumHit {
  0%   { background-size: 100%;}
  10%  { background-size: 95%; }
  30%  { background-size: 97%; }
  50%  { background-size: 100%;}
  60%  { background-size: 98%; }
  70%  { background-size: 100%;}
  80%  { background-size: 99%; }
  100% { background-size: 100%;}
}



	</style>
	<div id="drumkit-area" class="documenttext" style="display: none; position: absolute: left: 0px; top: 0px;">
	  <div id='jquery-drums' style="padding: 8px;">
	    <center>
	      <div style="display:inline-block;">
		<div style="position: relative;">
<!--
		  <img style="position: relative;" width="148" height="148"
		       src="{$httpCollection}/images/cymbal-overview.png" class="drum" id="drum1" border="0" />
-->
		  <div style="position: relative; width: 148px; height: 148px; background-image: url({$httpCollection}/images/cymbal-overview.png); background-repeat: no-repeat; background-size: 148px 148px" class="drum" id="drum1" border="0" ><xsl:comment>drum background</xsl:comment></div>
		  <div class="drumcontainer" style="color: #555555">
		    <span style="white-space: nowrap;">&lt;Shift-C&gt;</span>
		  </div>
		</div>
	      </div>
	      <div style="display:inline-block;">
		<div style="position: relative;">
<!--
		  <img style="position: relative;" width="148" height="144" 
		      src="{$httpCollection}/images/drum-overview.png" class="drum" id="drum3" border="0" />
-->
		  <div style="position: relative; width: 148px; height: 144px; background-image: url({$httpCollection}/images/drum-overview.png); background-repeat: no-repeat; background-size: 148px 144px" class="drum" id="drum3" border="0" ><xsl:comment>drum background</xsl:comment></div>
		  <div class="drumcontainer" >
		    <span style="white-space: nowrap;">&lt;Shift-V&gt;</span>
		  </div>
		</div>
	      </div>
	      <div style="display:inline-block;">
		<div style="position: relative;">
<!--
		  <img style="position: relative;"  width="167" height="163" 
		       src="{$httpCollection}/images/drum-overview.png" class="drum" id="drum2" border="0" />
-->
		  <div style="position: relative; width: 167px; height: 163px; background-image: url({$httpCollection}/images/drum-overview.png); background-repeat: no-repeat; background-size: 167px 163px" class="drum" id="drum2" border="0" ><xsl:comment>drum background</xsl:comment></div>
		  <div class="drumcontainer" >
		    <span style="white-space: nowrap;">&lt;Shift-B&gt;</span>
		  </div>
		</div>
	      </div>
	      <div style="display:inline-block;">
		<div style="position: relative;">
<!--
		  <img style="position: relative;" width="197" height="192" 
		       src="{$httpCollection}/images/drum-overview.png" class="drum" id="drum4" border="0" />
-->
		  <div style="position: relative; width: 197px; height: 192px; background-image: url({$httpCollection}/images/drum-overview.png); background-repeat: no-repeat; background-size: 197px 192px" class="drum" id="drum4" border="0" ><xsl:comment>drum background</xsl:comment></div>
		  <div class="drumcontainer" >
		    <span style="white-space: nowrap;">&lt;Shift-N&gt;</span>
		  </div>
		</div>
	      </div>
	      <div style="display:inline-block;">
		<div style="position: relative;">
<!--
		  <img style="position: relative;" width="216" height="211" 
		       src="{$httpCollection}/images/drum-overview.png" class="drum" id="drum5" border="0" />
-->
		  <div style="position: relative; width: 216px; height: 211px; background-image: url({$httpCollection}/images/drum-overview.png); background-repeat: no-repeat; background-size: 216px 211px" class="drum" id="drum5" border="0" ><xsl:comment>drum background</xsl:comment></div>
		  <div class="drumcontainer" >
		   <span style="white-space: nowrap;"> &lt;Shift-M&gt;</span>
		  </div>
		</div>
	      </div>
	    </center>
	  </div>
	  
	</div>


	<div id="guitar-area" class="documenttext" style="display: none; position: absolute: left: 0px; top: 0px;">
          <div style="color: white;">
	    <div id="jamWrapper">
	      <div id="jamStage">
		<xsl:comment><!--jamStage--></xsl:comment>
	      </div>
	      <div id="jamPlate">
		<xsl:comment><!--jamPlate--></xsl:comment>
	      </div>
	      <canvas id="jamStrings" width="750px" height="200px">
		Your browser does not support the Canvas element
	      </canvas>
	    </div>
	  </div>


	  <div style="position: relative; background-color: white;">
	    <div style="display:inline-block; width: 150px; height: 130px;">
	      <form style="position: absolute; top: 10px; leftXX: 10px;">

		<fieldset>
		  <legend id="clm-legend">Show Chords</legend>
		  
		  <div id="clm-div" class="radio-div">
		    
		    <div class="radio-label-combo">
		      <span>
			<input type="radio" id="clm-maj" name="clm-radio" onchange="setChordLineupMode('maj')" value="Maj"
			       checked="checked"/>
		      </span>
		      <label for="clm-maj" class="radio-label">
			<span>
			  Major
			</span>
		      </label>
		    </div>
		    
		  <div class="radio-label-combo">
		    <span>
		      <input type="radio" id="clm-min" name="clm-radio" onchange="setChordLineupMode('min')" value="Min"/>
		    </span>
		    <label for="clm-min" class="radio-label">
		      <span>
			Minor
		      </span>
		    </label>
		  </div>

		  <div class="radio-label-combo">
		    <span>
		      <input type="radio" id="clm-cus" name="clm-radio" onchange="setChordLineupMode('cus')" value="Cus"/>
		    </span>
		    <label for="clm-cus" class="radio-label">
		      <span>
			Custom
		      </span>
		    </label>
		  </div>

		  </div>
	      </fieldset>
	      </form>
	    </div>

<!--
	    <div id="mytab" style="display:inline-block; height: 160px; width: 780px;">
	      <svg class="graph" xmlns = "http://www.w3.org/2000/svg" width="100%" height="100%">
		<g id="scaled-mytab-group" transform="scale(0.45,0.55)">
		  <foreignobject id="scaled-mytab" width="2000px" height="300px"><xsl:comment>filler</xsl:comment></foreignobject>
		</g>
	      </svg>
	    </div>
-->


	    <gsf:div id="mytab" style="display:inline-block; heightXX: 130px; width: 780px;">
	      <gsf:div id="scaled-mytab" widthXX="2000px" heightXX="300px">
		

<!--		
		<gsf:div id="offscreen-jtab-chord-0" class="chordLineupBlock"/>
		  
		<div class="chordLineupBlock">
		  <gsf:div id="offscreen-jtab-chord-1"/>
		  <gsf:div id="offscreen-jtab-chord-2"/>
		</div>
		
		<gsf:div id="offscreen-jtab-chord-3" class="chordLineupBlock"/>
		
		<div class="chordLineupBlock">
		  <gsf:div id="offscreen-jtab-chord-4"/>
		  <gsf:div id="offscreen-jtab-chord-5"/>
		</div>
		
		<gsf:div id="offscreen-jtab-chord-6" class="chordLineupBlock"/>
		<gsf:div id="offscreen-jtab-chord-7" class="chordLineupBlock"/>
		
		<div class="chordLineupBlock">
		  <gsf:div id="offscreen-jtab-chord-8"/>
		  <gsf:div id="offscreen-jtab-chord-9"/>
		</div>
		
		<gsf:div id="offscreen-jtab-chord-10" class="chordLineupBlock"/>
		  
		<div class="chordLineupBlock">
		  <gsf:div id="offscreen-jtab-chord-11"/>
		  <gsf:div id="offscreen-jtab-chord-12"/>
		</div>
		
		<gsf:div id="offscreen-jtab-chord-13" class="chordLineupBlock"/>
		
		<div class="chordLineupBlock">
		  <gsf:div id="offscreen-jtab-chord-14"/>
		  <gsf:div id="offscreen-jtab-chord-15"/>
		</div>
		
		<gsf:div id="offscreen-jtab-chord-16" class="chordLineupBlock"/>		
-->

	      </gsf:div>
	      <gsf:div id="addCustomChord" style="display:none;">
		<input id="addCustomChordText" type="text" size="10"/>
		<input type="button" value="add custom chord" onclick="addCustomChord()"/>
	      </gsf:div>

	    </gsf:div>

	  </div>


	</div>

      </div>

      <div style="position: absolute; top: -300px; background-color: white;">
	<style>
	  .chordLineupXX {
  	    -webkit-transform-style: preserve-3d;
	    -moz-transform-style: preserve-3d;
	    transform-style: preserve-3d;
	  }

	  .chordLineupBlock {
	    display: inline-block;
	  }
	  
	  .chordLineupBlockVerticalCenterXX {
	    position: relative;
	    top: 50%;
	    transform: translataeY(-50%);
	    -webkit-transform: translataeY(-50%);
	    -ms-transform: translataeY(-50%);
	  }

	</style>


	<div id="offscreen-jtab-chord-lineup">
	  
	  <gsf:div id="offscreen-jtab-chord-0" class="chordLineupBlock"/>
	  
	  <div class="chordLineupBlock">
	    <gsf:div id="offscreen-jtab-chord-1"/>
	    <gsf:div id="offscreen-jtab-chord-2"/>
	  </div>
	  
	  <gsf:div id="offscreen-jtab-chord-3" class="chordLineupBlock"/>
	  
	  <div class="chordLineupBlock">
	    <gsf:div id="offscreen-jtab-chord-4"/>
	    <gsf:div id="offscreen-jtab-chord-5"/>
	  </div>
	  
	  <gsf:div id="offscreen-jtab-chord-6" class="chordLineupBlock"/>
	  <gsf:div id="offscreen-jtab-chord-7" class="chordLineupBlock"/>
	  
	  <div class="chordLineupBlock">
	    <gsf:div id="offscreen-jtab-chord-8"/>
	    <gsf:div id="offscreen-jtab-chord-9"/>
	  </div>

	  <gsf:div id="offscreen-jtab-chord-10" class="chordLineupBlock"/>
	  
	  <div class="chordLineupBlock">
	    <gsf:div id="offscreen-jtab-chord-11"/>
	    <gsf:div id="offscreen-jtab-chord-12"/>
	  </div>
	  
	  <gsf:div id="offscreen-jtab-chord-13" class="chordLineupBlock"/>
	  
	  <div class="chordLineupBlock">
	    <gsf:div id="offscreen-jtab-chord-14"/>
	    <gsf:div id="offscreen-jtab-chord-15"/>
	  </div>
	  
	  <gsf:div id="offscreen-jtab-chord-16" class="chordLineupBlock"/>
	  
	</div>



	<gsf:script>
          <![CDATA[

	  $(document).ready(function() {


            setChordLineupMode("maj");
	    chordChange("0");

            var lineup = jam_chords["maj"];
    
            // add click handler and scale down in size: one-time operation

            for (var i=0; i<lineup.length; i++) {
                $('#offscreen-jtab-chord-'+i).click(function(ii) { return function(e) { chordChange(ii) } }(i) );

                var $tab_svg = $('#offscreen-jtab-chord-'+i+'>div>svg');
		$tab_svg.attr("width", "58"); // go thinner than 'natural' width of 69 (for a height of 59)
		$tab_svg.attr("height","59");
		// True box is 0 0 138 118, but shaving off values so not so much white-space
		$tab_svg[0].setAttribute("viewBox","20 0 90 118"); // W3C DOM way to avoid jquery lower-casing 'viewBox' into 'viewbox'
		$tab_svg.parent().css("height","59px");
		//$tab_svg.parent().attr("height","59");
		//$tab_svg.parent().parent().attr("width","60");
		//$tab_svg.parent().parent().attr("height","59");
		
	    }

   

/*
            $('#offscreen-jtab-chord-0').click(function(e) { chordChange('0') });
            $('#offscreen-jtab-chord-1').click(function(e) { chordChange('1') });
            $('#offscreen-jtab-chord-2').click(function(e) { chordChange('2') });
            $('#offscreen-jtab-chord-3').click(function(e) { chordChange('3') });
            $('#offscreen-jtab-chord-4').click(function(e) { chordChange('4') });
            $('#offscreen-jtab-chord-5').click(function(e) { chordChange('5') });
            $('#offscreen-jtab-chord-6').click(function(e) { chordChange('6') });
            $('#offscreen-jtab-chord-7').click(function(e) { chordChange('7') });
            $('#offscreen-jtab-chord-8').click(function(e) { chordChange('8') });
            $('#offscreen-jtab-chord-9').click(function(e) { chordChange('9') });
            $('#offscreen-jtab-chord-10').click(function(e) { chordChange('10') });
            $('#offscreen-jtab-chord-11').click(function(e) { chordChange('11') });
            $('#offscreen-jtab-chord-12').click(function(e) { chordChange('12') });
            $('#offscreen-jtab-chord-13').click(function(e) { chordChange('13') });
            $('#offscreen-jtab-chord-14').click(function(e) { chordChange('14') });
            $('#offscreen-jtab-chord-15').click(function(e) { chordChange('15') });
            $('#offscreen-jtab-chord-16').click(function(e) { chordChange('16') });
*/

	    $('#scaled-mytab').append($('#offscreen-jtab-chord-lineup'));


	  });
        ]]>
	</gsf:script>
      </div>

    <div style="clear: both;"><xsl:comment>clear floats</xsl:comment></div>

    </div>




    <script>
      <xsl:text disable-output-escaping="yes">
	$(function(){
  	  transformToTurnstyleBlock("about");

  	  transformToTurnstyleBlock("video");
  	  transformToTurnstyleBlock("playlist");

  	  transformToTurnstyleBlock("piano");
	  transformToTurnstyleBlock("drumkit");
	  transformToTurnstyleBlock("guitar");

	  transformToTurnstyleBlock("analysis");

	  $('#video-openclose').trigger("click");

	});
	var piano_keyboard = new AudioSynthView();
	piano_keyboard.draw();     
      </xsl:text>
    </script>
    
  </div>

  <div style="color: white">
    <!--
	Sound
    -->
    x
  </div>
    
</div>

      <xsl:call-template name="audio-icon-cache"/>
    
      <hr/>
    
    </div>
  </xsl:template>



<xsl:template name="song-ul">

  <xsl:variable name="httpCollection">
    <xsl:value-of select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/>
  </xsl:variable>
  <xsl:variable name="assocFilePath">
    <gsf:metadata name="assocfilepath" select="root"/>
  </xsl:variable>
  <xsl:variable name="Source">
    <gsf:metadata name="Source" select="root"/>
  </xsl:variable>
  <xsl:variable name="Audio">
    <gsf:switch>
      <gsf:metadata name="Audio" select="root"/>
      <gsf:when test="exists">
	<gsf:metadata name="Audio" select="root"/>
      </gsf:when>
      <gsf:otherwise>doc.ogg</gsf:otherwise>
    </gsf:switch>
  </xsl:variable>
  <xsl:variable name="streamableaudio">
    <gsf:switch>
      <gsf:metadata name="streamableaudio" select="root"/>
      <gsf:when test="exists">
	<gsf:metadata name="streamableaudio" select="root"/>
      </gsf:when>
      <gsf:otherwise>doc.mp3</gsf:otherwise>
    </gsf:switch>
  </xsl:variable>
  
  <xsl:variable name="streamablevideo">
    <gsf:metadata name="Source"/>
  </xsl:variable>
  
  <gsf:variable name="cgiargFrameOffset">
    <xsl:value-of select="/page/pageRequest/paramList/param[@name='p.frameOffset']/@value"/>
  </gsf:variable>
  <gsf:variable name="cgiargFrameLength">
    <xsl:value-of select="/page/pageRequest/paramList/param[@name='p.frameLength']/@value"/>
  </gsf:variable>
  <xsl:variable name="cgiargYScaleSimImg">
    <xsl:choose>
      <xsl:when test="/page/pageRequest/paramList/param[@name='p.yScaleSimImg']/@value != ''">
	<xsl:value-of select="/page/pageRequest/paramList/param[@name='p.yScaleSimImg']/@value"/>
      </xsl:when>
      <xsl:otherwise>0.5</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <!--
      CAA = Content Analysis Algorithm
  -->
  <xsl:variable name="cgiargCAAlgorithm">
    <xsl:choose>
      <xsl:when test="/page/pageRequest/paramList/param[@name='p.caAlgorithm']/@value != ''">
	<xsl:value-of select="/page/pageRequest/paramList/param[@name='p.caAlgorithm']/@value"/>
					  </xsl:when>
					  <xsl:otherwise>1</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  
<!--
***
-->
<!--
Main Audio Player
-->
<!--
***
-->
  <ul class="playlist">
    <li class="rounded">
      <gsf:script src="{$httpCollection}/script/hybrid-audio-player.js"/>
      <a href="{$httpCollection}/index/assoc/{$assocFilePath}/{$streamableaudio}" id="mysong" onclick="togglePlayVisual(document.getElementById('mainPlayButton'))" style="padding-bottom: 2px;">
	<span><img height="32" id="mainPlayButton" onclick="var event = arguments[0] || window.event; togglePlay(event,this)" onmouseout="playHighlightOff(this)" onmouseover="playHighlightOn(this)" src="ext/diy-audio-player/images/play32.png" style="vertical-align: middle;" width="32"/>Play/Pause<span id="extraPlayText"/></span>
      </a>
      <gsf:script src="ext/diy-audio-player/script/audioDB-play.js"/>
      <xsl:choose>
	<xsl:when test="($cgiargFrameOffset != '-1') and ($cgiargFrameOffset != '')">
	  <div style="background-color: rgb(40%,40%,20%)">
	    <script type="text/javascript">
	      <xsl:text disable-output-escaping="yes">var frameOffsetStr=gs.variables.cgiargFrameOffset;
	      var frameLength=gs.variables.cgiargFrameLength;</xsl:text>
	    </script>
	    <svg height="24" id="svgAudioDBSegments" onLoadXX="svgAudioDBInit()" version="1.1" width="100%" xmlns="http://www.w3.org/2000/svg">
	  </svg>									</div>
	</xsl:when>
      </xsl:choose>
      <xsl:call-template name="structuredAudioPlayerBlock"/>
      <xsl:call-template name="processingPopup"/>
      <div id="doublePlay" style="width: 100%; display: none;">
	<script type="text/javascript">
	  <xsl:text disable-output-escaping="yes">// At time of writing this code, this needs to be an OGG file to work in Firefox
	  var source = "</xsl:text>
	  <gsf:metadata name="Audio" select="root"/>
	  <xsl:text disable-output-escaping="yes">";
	  
	  var self_sim_png = source.replace(/\.(ogg|mp3|wav)$/,".png");
	  var collect = "</xsl:text>
	  <xsl:value-of select="/page/pageResponse/collection/@name"/>
	  <xsl:text disable-output-escaping="yes">";
	  var site = "</xsl:text>
	  <xsl:value-of select="$site_name"/>
	  <xsl:text disable-output-escaping="yes">";</xsl:text>
	</script>
	<gsf:script src="ext/diy-audio-player/script/similarity-matrix-play.js"/>
	<audio controls="controls" id="leftsong" style="width: 49%;">
	  <!--
	      <source src="{$httpCollection}/index/assoc/{$assocFilePath}/doc.ogg" />
	  -->
	  <source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$streamableaudio}"/>
	  <source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$Audio}"/>
	  <source src="{$httpCollection}/index/assoc/{$assocFilePath}/doc.wav"/>
	</audio>
	<audio controls="controls" id="rightsong" style="width: 49%;">
	  <!--
	      <source src="{$httpCollection}/index/assoc/{$assocFilePath}/doc.ogg" />
	  -->
	  <source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$streamableaudio}"/>
	  <source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$Audio}"/>
	  <source src="{$httpCollection}/index/assoc/{$assocFilePath}/doc.wav"/>
								</audio>
      </div>
      <!--
	  Real Time Analysis (RTA) audio
      -->
      <div style="width: 100%;">
	<audio id="rta-audio-element" style="width: 100%;">
	  <!--
	      <source src="{$httpCollection}/index/assoc/{$assocFilePath}/doc.ogg"/>
	  -->
	  <source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$streamableaudio}"/>
	  <source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$Audio}"/>
	  <source src="{$httpCollection}/index/assoc/{$assocFilePath}/doc.wav"/>
	</audio>
      </div>
      <!--
	  <xsl:call-template name="workflow-block"/>
-->
      <div id="controlMarker">
	<xsl:comment> filler</xsl:comment>
      </div>
      <span class="ui-state-default ui-corner-top" id="overlayNewNotes" style="font-size:90%; padding: 3px; cursor:pointer;">New Annotation</span>
      <div id="svg-canvas-overlay" style="position: relative">
	<!--
	    drawing canvas
	-->
	<div style="width: 100%; position: absolute; left: 0px; top: 0px;">
	  <div style="position: relative">
	    <div>
	      <!--
		  **** better if 100% width, but issue with JS reading these values ???
	      -->
	      <canvas height="494" id="freq-plot" style="background-color: #cccccc;" width="941"/>
	    </div>
	  </div>
	</div>
	<div style="width: 100%; position: absolute; left: 0px; top: 0px;">
	  <div style="position: relative">
	    <div>
	      <!--
		  **** better if 100% width, but issue with JS reading these values ???
	      -->
	      <canvas height="494" id="freq-plot-labels" style="background-color: transparent" width="941"/>
	    </div>
	  </div>
	</div>
	<div style="width: 100%; position: absolute; left: 0px; top: 0px; display: none;">
	  <div style="position: relative">
	    <div>
	      <!--
		  **** better if 100% width, but issue with JS reading these values ???
	      -->
	      <canvas height="494" id="selfsim-plot" style="background-color: #0000cc;" width="941"/>
	    </div>
	  </div>
	</div>
	<!--
	    left/right-mix circle cursor
	-->
	<div style="background-color: transparent; position: relative; left: 0px; top: 0px;">
	  <svg id="svgSimilarityPlay" onLoad="svgInitSimilarityPlay()" version="1.1" width="100%" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
	    <g id="simPlayLineGroup" transform="scale(1.0,{$cgiargYScaleSimImg})">
	      <!--
		  image loaded here, with yScaleSimImg applied to group
	      -->
	      </g>										<g id="playtracker" onclick="dualPlay(evt)" onmousemove="playTrackerMove(evt)" onmouseout="playTrackerOff(evt)" style="visibility: hidden" transform="translate(0,0)">
	      <circle cx="0" cy="0" fill="rgba(100%,100%,50%,0.7)" r="20" stroke="black" stroke-width="1"/>
	      <circle cx="0" cy="0" fill="black" r="1" stroke="black" stroke-width="1"/>
	      <g style="visibility: hidden;" transform="translate(-15,-15)">
		<image height="30" id="playtrackerBusy" width="30" xlink:href="ext/diy-audio-player/images/wait30trans.gif"/>
	      </g>
	      <g>
		<g transform="rotate(-90)">
		  <g transform="translate(-20,-25)">
		    <text id="rightTime" style="font-size: 80%;">L: secs</text>
		  </g>
		</g>
		<g transform="translate(-20,30)">
		  <text id="leftTime" style="font-size: 80%;">R: secs</text>
		</g>
	      </g>
	    </g>
	  </svg>
	</div>
	<gsf:variable-array name="salami.overlayNote">
	  <gsf:metadata multiple="true" name="salami.overlayNote" separator=", "/>
	</gsf:variable-array>
	<!--
	    onclick="var event = arguments[0] || window.event; dualPlay(event)"
	    onmousemove="var event = arguments[0] || window.event; playTrackerMove(event)"
	    onmouseout="var event = arguments[0] || window.event; playTrackerOff(event)"
	-->
	<div id="noteOverlay" style="width: 100%; height: 494px; position: absolute; left: 0px; top: 0px; background-color: transparent;">								</div>								<gsf:script>$(window).load(function(){ 
	// **** currently supressed for respooled!!!!								
	//var overlayNotes = new OverlayNotes("noteOverlay","salami.overlayNote"); 
	//$('#overlayNewNotes').click(function() {overlayNotes.AddNote()});
	//addStatusBar(); 
	});</gsf:script>
      </div>
      <!--
	  end of svg-canvas-overly
      -->
      <xsl:call-template name="visualization-mode-block"/>
    </li>
  </ul>
  
</xsl:template>

</xsl:stylesheet>
